@@ -54,7 +54,6 @@
 #include "libclamav/clamav.h"
 #include "libclamav/others.h"
 
-#include "shared/memory.h"
 #include "shared/output.h"
 #include "shared/options.h"
 #include "shared/cfgparser.h"
@@ -261,13 +260,6 @@ int main(int argc, char **argv)
     }
 #endif
 
-    logg("#clamd daemon "VERSION" (OS: "TARGET_OS_TYPE", ARCH: "TARGET_ARCH_TYPE", CPU: "TARGET_CPU_TYPE")\n");
-
-    if(logg_size)
-	logg("#Log file size limited to %d bytes.\n", logg_size);
-    else
-	logg("#Log file size limit disabled.\n");
-
 #ifdef C_LINUX
     procdev = 0;
     if(stat("/proc", &sb) != -1 && !sb.st_size)
@@ -304,9 +296,16 @@ int main(int argc, char **argv)
     } else
         foreground = 1;
 
+    logg("clamd daemon "VERSION" (OS: "TARGET_OS_TYPE", ARCH: "TARGET_ARCH_TYPE", CPU: "TARGET_CPU_TYPE")\n");
+
+    if(logg_size)
+	logg("Log file size limited to %d bytes.\n", logg_size);
+    else
+	logg("Log file size limit disabled.\n");
+
     /* load the database(s) */
     dbdir = cfgopt(copt, "DatabaseDirectory")->strarg;
-    logg("#Reading databases from %s\n", dbdir);
+    logg("Reading databases from %s\n", dbdir);
 
     if(cfgopt(copt, "PhishingSignatures")->enabled)
 	dboptions |= CL_DB_PHISHING;
@@ -343,7 +342,7 @@ int main(int argc, char **argv)
 	return 1;
     }
 
-    logg("#Loaded %d signatures.\n", sigs);
+    logg("Loaded %d signatures.\n", sigs);
     if((ret = cl_build(engine)) != 0) {
 	logg("!Database initialization error: %s\n", cl_strerror(ret));;
 	logg_close();
