@@ -27,8 +27,8 @@
 #include <stdlib.h>
 #include "shared/cfgparser.h"
 
-int poll_fds(int *fds, int nfds, int timeout_sec);
-int poll_fd(int fd, int timeout_sec);
+int poll_fds(int *fds, int nfds, int timeout_sec, int check_signals);
+int poll_fd(int fd, int timeout_sec, int check_signals);
 int is_fd_connected(int fd);
 void virusaction(const char *filename, const char *virname, const struct cfgstruct *copt);
 int writen(int fd, void *buff, unsigned int count);
