@@ -42,7 +42,6 @@
 
 #include "libclamav/clamav.h"
 
-#include "shared/memory.h"
 #include "shared/output.h"
 
 #include "server.h"
@@ -182,7 +181,7 @@ static struct cl_engine *reload_db(struct cl_engine *engine, unsigned int dbopti
 {
 	const char *dbdir;
 	int retval;
-	unsigned int sigs = 0;
+	unsigned int sigs = 0, try = 1;
 
     *ret = 0;
     if(do_check) {
@@ -210,7 +209,7 @@ static struct cl_engine *reload_db(struct cl_engine *engine, unsigned int dbopti
     logg("Reading databases from %s\n", dbdir);
 
     if(dbstat == NULL) {
-	dbstat = (struct cl_stat *) mmalloc(sizeof(struct cl_stat));
+	dbstat = (struct cl_stat *) malloc(sizeof(struct cl_stat));
 	if(!dbstat) {
 	    logg("!Can't allocate memory for dbstat\n");
 	    *ret = 1;
@@ -227,7 +226,13 @@ static struct cl_engine *reload_db(struct cl_engine *engine, unsigned int dbopti
 	return NULL;
     }
 
-    if((retval = cl_load(dbdir, &engine, &sigs, dboptions))) {
+    while((retval = cl_load(dbdir, &engine, &sigs, dboptions)) == CL_ELOCKDB) {
+	logg("!reload db failed: %s (try %u)\n", cl_strerror(retval), try);
+	if(++try > 3)
+	    break;
+    }
+
+    if(retval) {
 	logg("!reload db failed: %s\n", cl_strerror(retval));
 	*ret = 1;
 	return NULL;
@@ -251,7 +256,7 @@ static struct cl_engine *reload_db(struct cl_engine *engine, unsigned int dbopti
 
 int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigned int dboptions, const struct cfgstruct *copt)
 {
-	int new_sd, max_threads, i, ret = 0;
+	int max_threads, i, ret = 0;
 	unsigned int options = 0;
 	threadpool_t *thr_pool;
 #ifndef	C_WINDOWS
@@ -412,6 +417,13 @@ int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigne
 	logg("OLE2 support disabled.\n");
     }
 
+    if(cfgopt(copt, "ScanPDF")->enabled) {
+	logg("PDF support enabled.\n");
+	options |= CL_SCAN_PDF;
+    } else {
+	logg("PDF support disabled.\n");
+    }
+
     if(cfgopt(copt, "ScanHTML")->enabled) {
 	logg("HTML support enabled.\n");
 	options |= CL_SCAN_HTML;
@@ -460,7 +472,7 @@ int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigne
 	pthread_attr_init(&clamuko_attr);
 	pthread_attr_setdetachstate(&clamuko_attr, PTHREAD_CREATE_JOINABLE);
 
-	tharg = (struct thrarg *) mmalloc(sizeof(struct thrarg));
+	tharg = (struct thrarg *) malloc(sizeof(struct thrarg));
 	tharg->copt = copt;
 	tharg->engine = engine;
 	tharg->limits = &limits;
@@ -516,17 +528,22 @@ int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigne
     time(&start_time);
 
     for(;;) {				
-	struct stat st_buf;
+#if !defined(C_WINDOWS) && !defined(C_BEOS)
+	    struct stat st_buf;
+#endif
     	int socketd = socketds[0];
+	int new_sd = 0;
+
     	if(nsockets > 1) {
-    	    int pollret = poll_fds(socketds, nsockets, -1);
+	    int pollret = poll_fds(socketds, nsockets, -1, 1);
     	    if(pollret > 0) {
     		socketd = socketds[pollret - 1];
     	    } else {
-    		socketd = socketds[0]; /* on a poll error use the first socket */
+		new_sd = -1;
     	    }
-    	}    
-	if(fstat(socketd, &st_buf) == -1) {
+    	}
+#if !defined(C_WINDOWS) && !defined(C_BEOS)
+	if(new_sd != -1 && fstat(socketd, &st_buf) == -1) {
 	    logg("!fstat(): socket descriptor gone\n");
 	    memmove(socketds, socketds + 1, sizeof(socketds[0]) * nsockets);
 	    nsockets--;
@@ -535,7 +552,9 @@ int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigne
 		break;
 	    }
 	}
-	new_sd = accept(socketd, NULL, NULL);
+#endif
+	if (new_sd != -1)
+	    new_sd = accept(socketd, NULL, NULL);
 	if((new_sd == -1) && (errno != EINTR)) {
 	    if(progexit) {
 	    	break;
@@ -559,7 +578,7 @@ int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigne
 	}
 
 	if (!progexit && new_sd >= 0) {
-		client_conn = (client_conn_t *) mmalloc(sizeof(struct client_conn_tag));
+		client_conn = (client_conn_t *) malloc(sizeof(struct client_conn_tag));
 		client_conn->sd = new_sd;
 		client_conn->options = options;
 		client_conn->copt = copt;
