@@ -13,7 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #ifndef __SESSION_H
@@ -36,10 +37,11 @@
 #define CMD10 "END"
 #define CMD11 "SHUTDOWN"
 #define CMD12 "FD"
+#define CMD13 "MULTISCAN"
 
-#include <clamav.h>
-#include "cfgparser.h"
+#include "libclamav/clamav.h"
+#include "shared/cfgparser.h"
 
-int command(int desc, const struct cl_node *root, const struct cl_limits *limits, int options, const struct cfgstruct *copt, int timeout);
+int command(int desc, const struct cl_engine *engine, const struct cl_limits *limits, unsigned int options, const struct cfgstruct *copt, int timeout);
 
 #endif
