@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002 Tomasz Kojm <zolw@konarski.edu.pl>
+ *  Copyright (C) 2002 - 2005 Tomasz Kojm <tkojm@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
+#ifdef	_MSC_VER
+#include <winsock.h>
+#endif
+
 #if HAVE_CONFIG_H
 #include "clamav-config.h"
 #endif
@@ -23,53 +28,57 @@
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifndef	C_WINDOWS
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <clamav.h>
+#endif
 #include <errno.h>
+#ifndef	C_WINDOWS
 #include <netdb.h>
+#endif
 
+#include "libclamav/clamav.h"
+
+#include "shared/options.h"
+#include "shared/cfgparser.h"
+#include "shared/output.h"
+#include "shared/network.h"
 
-#include "options.h"
-#include "cfgparser.h"
-#include "defaults.h"
 #include "others.h"
 #include "server.h"
-#include "output.h"
+#include "tcpserver.h"
 
-int tcpserver(const struct optstruct *opt, const struct cfgstruct *copt, struct cl_node *root)
+int tcpserver(const struct cfgstruct *copt)
 {
 	struct sockaddr_in server;
 	int sockfd, backlog;
-	struct cfgstruct *cpt;
 	struct cfgstruct *taddr;
-	struct hostent *he;
-	char *estr;
+	struct hostent he;
+	char *estr, buf[1024];
 	int true = 1;
 
     memset((char *) &server, 0, sizeof(server));
     server.sin_family = AF_INET;
     server.sin_port = htons(cfgopt(copt, "TCPSocket")->numarg);
 
-
-    if((taddr = cfgopt(copt, "TCPAddr"))) {
-	if ((he = gethostbyname(taddr->strarg)) == 0) {
-	    logg("!gethostbyname(%s) error: %s\n", taddr->strarg, strerror(errno));
-	    exit(1);
+    if((taddr = cfgopt(copt, "TCPAddr"))->enabled) {
+	if(r_gethostbyname(taddr->strarg, &he, buf, sizeof(buf)) == -1) {
+	    logg("!r_gethostbyname(%s) error: %s\n", taddr->strarg, strerror(errno));
+	    return -1;
 	}
-	server.sin_addr = *(struct in_addr *) he->h_addr_list[0];
+	server.sin_addr = *(struct in_addr *) he.h_addr_list[0];
     } else
 	server.sin_addr.s_addr = INADDR_ANY;
 
 
     if((sockfd = socket(AF_INET, SOCK_STREAM, 0)) == -1) {
 	estr = strerror(errno);
-	/*
-	fprintf(stderr, "ERROR: socket() error: %s\n", estr);
-	*/
 	logg("!socket() error: %s\n", estr);
-	exit(1);
+	return -1;
     }
 
     if(setsockopt(sockfd, SOL_SOCKET, SO_REUSEADDR, (void *) &true, sizeof(true)) == -1) {
@@ -78,38 +87,25 @@ int tcpserver(const struct optstruct *opt, const struct cfgstruct *copt, struct
 
     if(bind(sockfd, (struct sockaddr *) &server, sizeof(struct sockaddr_in)) == -1) {
 	estr = strerror(errno);
-	/* 
-	fprintf(stderr, "ERROR: can't bind(): %s\n", estr);
-	*/
 	logg("!bind() error: %s\n", estr);
-	exit(1);
+	close(sockfd);
+	return -1;
     } else {
-	if ( taddr != NULL && *taddr->strarg )
-	    logg("Bound to address %s on port %d\n", taddr->strarg, cfgopt(copt, "TCPSocket")->numarg);
+	if(taddr->enabled)
+	    logg("Bound to address %s on tcp port %d\n", taddr->strarg, cfgopt(copt, "TCPSocket")->numarg);
 	else
-	    logg("Bound to port %d\n", cfgopt(copt, "TCPSocket")->numarg);
+	    logg("Bound to tcp port %d\n", cfgopt(copt, "TCPSocket")->numarg);
     }
 
-    if((cpt = cfgopt(copt, "MaxConnectionQueueLength")))
-	backlog = cpt->numarg;
-    else
-	backlog = CL_DEFAULT_BACKLOG;
-
+    backlog = cfgopt(copt, "MaxConnectionQueueLength")->numarg;
     logg("Setting connection queue length to %d\n", backlog);
 
     if(listen(sockfd, backlog) == -1) {
 	estr = strerror(errno);
-	/*
-	fprintf(stderr, "ERROR: listen() error: %s\n", estr);
-	*/
 	logg("!listen() error: %s\n", estr);
-	exit(1);
+	close(sockfd);
+	return -1;
     }
 
-    /* if(cfgopt(copt, "UseProcesses"))
-	acceptloop_proc(sockfd, root, copt);
-    else */
-	acceptloop_th(sockfd, root, copt);
-
-    return 0;
+    return sockfd;
 }
