@@ -20,6 +20,10 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *  MA 02110-1301, USA.
  */
+ 
+#ifdef	_MSC_VER
+#include <winsock.h>	/* only needed in CL_EXPERIMENTAL */
+#endif
 
 #if HAVE_CONFIG_H
 #include "clamav-config.h"
@@ -27,14 +31,20 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef	HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <string.h>
 #include <ctype.h>
+#ifndef	C_WINDOWS
 #include <netinet/in.h>
 #include <netdb.h>
+#endif
 #include <sys/types.h>
+#ifndef	C_WINDOWS
 #include <sys/socket.h>
 #include <sys/time.h>
+#endif
 #include <time.h>
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -52,7 +62,6 @@
 #include "shared/cfgparser.h"
 #include "shared/output.h"
 #include "shared/misc.h"
-#include "shared/memory.h"
 #include "shared/cdiff.h"
 
 #include "libclamav/clamav.h"
@@ -64,6 +73,9 @@
 #define	O_BINARY	0
 #endif
 
+#ifndef	C_WINDOWS
+#define	closesocket(s)	close(s)
+#endif
 
 static int wwwconnect(const char *server, const char *proxy, int pport, char *ip, const char *localip, int ctimeout, struct mirdat *mdat)
 {
@@ -144,7 +156,9 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 		else
 			port = 8080;
 
+#ifndef	C_WINDOWS
 		endservent();
+#endif
 #else
 		port = 8080;
 #endif
@@ -156,7 +170,7 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
     }
 
     if((host = gethostbyname(hostpt)) == NULL) {
-	const char *herr;
+	char *herr;
 	switch(h_errno) {
 	    case HOST_NOT_FOUND:
 		herr = "Host not found";
@@ -269,14 +283,14 @@ static char *proxyauth(const char *user, const char *pass)
 	char *buf, *userpass, *auth;
 
 
-    userpass = mmalloc(strlen(user) + strlen(pass) + 2);
+    userpass = malloc(strlen(user) + strlen(pass) + 2);
     if(!userpass) {
 	logg("!proxyauth: Can't allocate memory for 'userpass'\n");
 	return NULL;
     }
     sprintf(userpass, "%s:%s", user, pass);
 
-    buf = mmalloc((strlen(pass) + strlen(user)) * 2 + 4);
+    buf = malloc((strlen(pass) + strlen(user)) * 2 + 4);
     if(!buf) {
 	logg("!proxyauth: Can't allocate memory for 'buf'\n");
 	free(userpass);
@@ -286,7 +300,7 @@ static char *proxyauth(const char *user, const char *pass)
     len = fmt_base64(buf, userpass, strlen(userpass));
     free(userpass);
     buf[len] = '\0';
-    auth = mmalloc(strlen(buf) + 30);
+    auth = malloc(strlen(buf) + 30);
     if(!auth) {
 	logg("!proxyauth: Can't allocate memory for 'authorization'\n");
 	return NULL;
@@ -311,7 +325,7 @@ static struct cl_cvd *remote_cvdhead(const char *file, const char *hostname, cha
 
 
     if(proxy) {
-        remotename = mmalloc(strlen(hostname) + 8);
+        remotename = malloc(strlen(hostname) + 8);
 	if(!remotename) {
 	    logg("!remote_cvdhead: Can't allocate memory for 'remotename'\n");
 	    return NULL;
@@ -376,9 +390,9 @@ static struct cl_cvd *remote_cvdhead(const char *file, const char *hostname, cha
     if(!ip[0])
 	strcpy(ip, ipaddr);
 
-    if(write(sd, cmd, strlen(cmd)) < 0) {
+    if(send(sd, cmd, strlen(cmd), 0) < 0) {
 	logg("!remote_cvdhead: write failed\n");
-	close(sd);
+	closesocket(sd);
 	return NULL;
     }
 
@@ -394,7 +408,7 @@ static struct cl_cvd *remote_cvdhead(const char *file, const char *hostname, cha
 	if(cnt <= 0)
 	    break;
     }
-    close(sd);
+    closesocket(sd);
 
     if(bread == -1) {
 	logg("!remote_cvdhead: Error while reading CVD header from %s\n", hostname);
@@ -476,7 +490,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
 
 
     if(proxy) {
-        remotename = mmalloc(strlen(hostname) + 8);
+        remotename = malloc(strlen(hostname) + 8);
 	if(!remotename) {
 	    logg("!getfile: Can't allocate memory for 'remotename'\n");
 	    return 75; /* FIXME */
@@ -525,7 +539,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
     if(!ip[0])
 	strcpy(ip, ipaddr);
 
-    if(write(sd, cmd, strlen(cmd)) < 0) {
+    if(send(sd, cmd, strlen(cmd), 0) < 0) {
 	logg("!getfile: Can't write to socket\n");
 	return 52;
     }
@@ -565,7 +579,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
     if((strstr(buffer, "HTTP/1.1 404")) != NULL || (strstr(buffer, "HTTP/1.0 404")) != NULL) { 
 	logg("!getfile: %s not found on remote server (IP: %s)\n", srcfile, ipaddr);
 	/* mirman_update(mdat->currip, mdat, 1); */
-	close(sd);
+	closesocket(sd);
 	return 58;
     }
 
@@ -573,7 +587,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
        !strstr(buffer, "HTTP/1.1 206") && !strstr(buffer, "HTTP/1.0 206")) {
 	logg("!getfile: Unknown response from remote server (IP: %s)\n", ipaddr);
 	mirman_update(mdat->currip, mdat, 1);
-	close(sd);
+	closesocket(sd);
 	return 58;
     }
 
@@ -596,7 +610,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
 	getcwd(currdir, sizeof(currdir));
 	logg("!getfile: Can't create new file %s in %s\n", destfile, currdir);
 	logg("Hint: The database directory must be writable for UID %d or GID %d\n", getuid(), getgid());
-	close(sd);
+	closesocket(sd);
 	return 57;
     }
 
@@ -609,7 +623,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
 	    logg("getfile: Can't write %d bytes to %s\n", bread, destfile);
 	    unlink(destfile);
 	    close(fd);
-	    close(sd);
+	    closesocket(sd);
 	    return 57; /* FIXME */
 	}
 
@@ -626,7 +640,7 @@ static int getfile(const char *srcfile, const char *destfile, const char *hostna
             fflush(stdout);
         }
     }
-    close(sd);
+    closesocket(sd);
     close(fd);
 
     if(totalsize > 0)
@@ -715,7 +729,7 @@ static int chdir_inc(const char *dbname)
 
 	if(cvd_unpack(dbfile, path) == -1) {
 	    logg("!chdir_inc: Can't unpack %s into %s\n", dbfile, path);
-	    rmdirs(path);
+	    cli_rmdirs(path);
 	    return -1;
 	}
     }
@@ -822,7 +836,7 @@ static int updatedb(const char *dbname, const char *hostname, char *ip, int *sig
 	inc = 0;
 	if(stat(dbinc, &sb) != -1) {
 	    logg("^Removing corrupted incremental directory %s\n", dbinc);
-	    if(rmdirs(dbinc)) {
+	    if(cli_rmdirs(dbinc)) {
 		logg("!Can't remove incremental directory\n");
 		return 53;
 	    }
@@ -998,14 +1012,14 @@ static int updatedb(const char *dbname, const char *hostname, char *ip, int *sig
 	    if(ret) {
 		if(bacinc) {
 		    logg("*Restoring incremental directory %s from backup\n", dbinc);
-		    rmdirs(dbinc);
+		    cli_rmdirs(dbinc);
 		    rename(bacinc, dbinc);
 		    free(bacinc);
 		}
 		return ret;
 	    } else {
 		logg("*Removing incremental directory %s\n", dbinc);
-		rmdirs(dbinc);
+		cli_rmdirs(dbinc);
 	    }
 
 	} else {
@@ -1014,7 +1028,7 @@ static int updatedb(const char *dbname, const char *hostname, char *ip, int *sig
 
 	if(bacinc) {
 	    logg("*Removing backup directory %s\n", bacinc);
-	    rmdirs(bacinc);
+	    cli_rmdirs(bacinc);
 	    free(bacinc);
 	}
     }
@@ -1026,7 +1040,7 @@ static int updatedb(const char *dbname, const char *hostname, char *ip, int *sig
     }
 
     if(nodb && inc)
-	rmdirs(dbinc);
+	cli_rmdirs(dbinc);
 
     logg("%s updated (version: %d, sigs: %d, f-level: %d, builder: %s)\n", inc ? dbinc : dbfile, current->version, current->sigs, current->fl, current->builder);
 
@@ -1106,7 +1120,7 @@ int downloadmanager(const struct cfgstruct *copt, const struct optstruct *opt, c
 		    if(vwarning && !strstr(cl_retver(), "devel") && !strstr(cl_retver(), "rc")) {
 			if(strcmp(cl_retver(), newver)) {
 			    logg("^Your ClamAV installation is OUTDATED!\n");
-			    logg("^Local version: %s Recommended version: %s\n", cl_retver(), pt);
+			    logg("^Local version: %s Recommended version: %s\n", cl_retver(), newver);
 			    logg("DON'T PANIC! Read http://www.clamav.net/support/faq\n");
 			    outdated = 1;
 			}
@@ -1214,7 +1228,7 @@ int downloadmanager(const struct cfgstruct *copt, const struct optstruct *opt, c
 		char *cmd = strdup(arg);
 
 	    if((pt = strstr(cmd, "%v")) && newver && isdigit(*newver)) {
-		    char *buffer = (char *) mcalloc(strlen(cmd) + strlen(newver) + 10, sizeof(char));
+		    char *buffer = (char *) malloc(strlen(cmd) + strlen(newver) + 10);
 
 		if(!buffer) {
 		    logg("!downloadmanager: Can't allocate memory for buffer\n");
