@@ -132,10 +132,10 @@ blobSetFilename(blob *b, const char *dir, const char *filename)
 	if(b->name)
 		free(b->name);
 
-	b->name = strdup(filename);
+	b->name = cli_strdup(filename);
 
 	if(b->name)
-		sanitiseName(b->name);
+		cli_sanitise_filename(b->name);
 }
 
 const char *
@@ -559,26 +559,3 @@ fileblobContainsVirus(const fileblob *fb)
 {
 	return fb->isInfected ? TRUE : FALSE;
 }
-
-/*
- * Different operating systems allow different characters in their filenames
- * FIXME: What does QNX want? There is no #ifdef C_QNX, but if there were
- *	it may be best to treat it like MSDOS
- */
-void
-sanitiseName(char *name)
-{
-	while(*name) {
-#ifdef	C_DARWIN
-		*name &= '\177';
-#endif
-		/* Also check for tab - "Heinz Martin" <Martin@hemag.ch> */
-#if	defined(MSDOS) || defined(C_CYGWIN) || defined(C_WINDOWS) || defined(C_OS2)
-		if(strchr("%/*?<>|\\\"+=,;:\t ~", *name))
-#else
-		if(*name == '/')
-#endif
-			*name = '_';
-		name++;
-	}
-}
