@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 - 2005 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2003 - 2006 Tomasz Kojm <tkojm@clamav.net>
  *
  *  untgz() is based on public domain minitar utility by Charles G. Waldman
  *
@@ -15,7 +15,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #if HAVE_CONFIG_H
@@ -28,13 +29,18 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <zlib.h>
+#ifdef	HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#include "zlib.h"
 #include <time.h>
+#include <errno.h>
 
 #include "clamav.h"
 #include "others.h"
 #include "dsig.h"
 #include "str.h"
+#include "cvd.h"
 
 #define TAR_BLOCKSIZE 512
 
@@ -50,12 +56,15 @@ int cli_untgz(int fd, const char *destdir)
     cli_dbgmsg("in cli_untgz()\n");
 
     if((infile = gzdopen(fd, "rb")) == NULL) {
-	cli_errmsg("Can't gzdopen() descriptor %d\n", fd);
+	cli_errmsg("Can't gzdopen() descriptor %d, errno = %d\n", fd, errno);
 	return -1;
     }
 
-
-    fullname = (char *) calloc(sizeof(char), strlen(destdir) + 100 + 5);
+    fullname = (char *) cli_calloc(sizeof(char), strlen(destdir) + 100 + 5);
+    if(!fullname) {
+	cli_errmsg("cli_untgz: Can't allocate memory for fullname\n");
+	return -1;
+    }
 
     while(1) {
 
@@ -173,6 +182,10 @@ struct cl_cvd *cl_cvdparse(const char *head)
     }
 
     cvd = (struct cl_cvd *) cli_calloc(1, sizeof(struct cl_cvd));
+    if(!cvd) {
+	cli_errmsg("cl_cvdparse: Can't allocate memory for cvd\n");
+	return NULL;
+    }
 
     if(!(cvd->time = cli_strtok(head, 1, ":"))) {
 	cli_errmsg("CVD -> Can't extract time from header.\n");
@@ -204,7 +217,7 @@ struct cl_cvd *cl_cvdparse(const char *head)
 	free(cvd);
 	return NULL;
     }
-    cvd->fl = (short int) atoi(pt);
+    cvd->fl = atoi(pt);
     free(pt);
 
     if(!(cvd->md5 = cli_strtok(head, 5, ":"))) {
@@ -243,25 +256,30 @@ struct cl_cvd *cl_cvdparse(const char *head)
 
 struct cl_cvd *cl_cvdhead(const char *file)
 {
-	FILE *fd;
-	char head[513];
+	FILE *fs;
+	char head[513], *pt;
 	int i;
+	unsigned int bread;
 
-    if((fd = fopen(file, "rb")) == NULL) {
+
+    if((fs = fopen(file, "rb")) == NULL) {
 	cli_dbgmsg("Can't open CVD file %s\n", file);
 	return NULL;
     }
 
-    if((i = fread(head, 1, 512, fd)) != 512) {
-	cli_dbgmsg("Short read (%d) while reading CVD head from %s\n", i, file);
-	fclose(fd);
+    if(!(bread = fread(head, 1, 512, fs))) {
+	cli_errmsg("Can't read CVD header of %s\n", file);
+	fclose(fs);
 	return NULL;
     }
 
-    fclose(fd);
+    fclose(fs);
 
-    head[512] = 0;
-    for(i = 511; i > 0 && (head[i] == ' ' || head[i] == 10); head[i] = 0, i--);
+    head[bread] = 0;
+    if((pt = strpbrk(head, "\n\r")))
+	*pt = 0;
+    
+    for(i = bread - 1; i > 0 && (head[i] == ' ' || head[i] == '\n' || head[i] == '\r'); head[i] = 0, i--);
 
     return cl_cvdparse(head);
 }
@@ -275,14 +293,14 @@ void cl_cvdfree(struct cl_cvd *cvd)
     free(cvd);
 }
 
-int cli_cvdverify(FILE *fd, struct cl_cvd *cvdpt)
+static int cli_cvdverify(FILE *fs, struct cl_cvd *cvdpt)
 {
 	struct cl_cvd *cvd;
 	char *md5, head[513];
 	int i;
 
-    fseek(fd, 0, SEEK_SET);
-    if(fread(head, 1, 512, fd) != 512) {
+    fseek(fs, 0, SEEK_SET);
+    if(fread(head, 1, 512, fs) != 512) {
 	cli_dbgmsg("Can't read CVD head from stream\n");
 	return CL_ECVD;
     }
@@ -296,7 +314,7 @@ int cli_cvdverify(FILE *fd, struct cl_cvd *cvdpt)
     if(cvdpt)
 	memcpy(cvdpt, cvd, sizeof(struct cl_cvd));
 
-    md5 = cli_md5stream(fd, NULL);
+    md5 = cli_md5stream(fs, NULL);
     cli_dbgmsg("MD5(.tar.gz) = %s\n", md5);
 
     if(strncmp(md5, cvd->md5, 32)) {
@@ -322,39 +340,38 @@ int cli_cvdverify(FILE *fd, struct cl_cvd *cvdpt)
 
 int cl_cvdverify(const char *file)
 {
-	FILE *fd;
+	FILE *fs;
 	int ret;
 
-    if((fd = fopen(file, "rb")) == NULL) {
+    if((fs = fopen(file, "rb")) == NULL) {
 	cli_errmsg("Can't open CVD file %s\n", file);
 	return CL_EOPEN;
     }
 
-    ret = cli_cvdverify(fd, NULL);
-    fclose(fd);
+    ret = cli_cvdverify(fs, NULL);
+    fclose(fs);
 
     return ret;
 }
 
-int cli_cvdload(FILE *fd, struct cl_node **root, unsigned int *signo, short warn)
+int cli_cvdload(FILE *fs, struct cl_engine **engine, unsigned int *signo, short warn, unsigned int options)
 {
-        char *dir, *tmp, *buffer;
+        char *dir;
 	struct cl_cvd cvd;
-	int bytes, ret;
-	FILE *tmpd;
-	time_t stime;
+	int ret, fd;
+	time_t s_time;
 
 
     cli_dbgmsg("in cli_cvdload()\n");
 
     /* verify */
 
-    if((ret = cli_cvdverify(fd, &cvd)))
+    if((ret = cli_cvdverify(fs, &cvd)))
 	return ret;
 
     if(cvd.stime && warn) {
-	time(&stime);
-	if((int) stime - cvd.stime > 604800) {
+	time(&s_time);
+	if((int) s_time - cvd.stime > 604800) {
 	    cli_warnmsg("**************************************************\n");
 	    cli_warnmsg("***  The virus database is older than 7 days.  ***\n");
 	    cli_warnmsg("***        Please update it IMMEDIATELY!       ***\n");
@@ -363,78 +380,43 @@ int cli_cvdload(FILE *fd, struct cl_node **root, unsigned int *signo, short warn
     }
 
     if(cvd.fl > cl_retflevel()) {
-	cli_warnmsg("********************************************************\n");
-	cli_warnmsg("***  This version of the ClamAV engine is outdated.  ***\n");
-	cli_warnmsg("*** DON'T PANIC! Read http://www.clamav.net/faq.html ***\n");
-	cli_warnmsg("********************************************************\n");
+	cli_warnmsg("***********************************************************\n");
+	cli_warnmsg("***  This version of the ClamAV engine is outdated.     ***\n");
+	cli_warnmsg("*** DON'T PANIC! Read http://www.clamav.net/support/faq ***\n");
+	cli_warnmsg("***********************************************************\n");
     }
 
-    fseek(fd, 512, SEEK_SET);
+    if((fd = dup(fileno(fs))) == -1) {
+	cli_errmsg("cli_cvdload(): Can't duplicate descriptor %d\n", fileno(fs));
+	return CL_EIO;
+    }
+
+    if(lseek(fd, 512, SEEK_SET) == -1) {
+	cli_errmsg("cli_cvdload(): Can't lseek descriptor %d\n", fd);
+	close(fd);
+	return CL_EIO;
+    }
 
     dir = cli_gentemp(NULL);
     if(mkdir(dir, 0700)) {
-	cli_errmsg("cli_cvdload():  Can't create temporary directory %s\n", dir);
+	cli_errmsg("cli_cvdload(): Can't create temporary directory %s\n", dir);
+	free(dir);
+	close(fd);
 	return CL_ETMPDIR;
     }
 
-    /* 
-    if(cli_untgz(fileno(fd), dir)) {
+    if(cli_untgz(fd, dir)) {
+	close(fd);
 	cli_errmsg("cli_cvdload(): Can't unpack CVD file.\n");
+	free(dir);
 	return CL_ECVDEXTR;
     }
-    */
-
-    /* FIXME: it seems there is some problem with current position indicator
-     * after gzdopen() call in cli_untgz(). Temporarily we need this wrapper:
-     */
-
-	    /* start */
-
-	    tmp = cli_gentemp(NULL);
-	    if((tmpd = fopen(tmp, "wb+")) == NULL) {
-		cli_errmsg("Can't create temporary file %s\n", tmp);
-		free(dir);
-		free(tmp);
-		return CL_ETMPFILE;
-	    }
-
-	    if(!(buffer = (char *) cli_malloc(FILEBUFF))) {
-		free(dir);
-		free(tmp);
-		fclose(tmpd);
-		return CL_EMEM;
-	    }
-
-	    while((bytes = fread(buffer, 1, FILEBUFF, fd)) > 0)
-		fwrite(buffer, 1, bytes, tmpd);
-
-	    free(buffer);
-
-	    fflush(tmpd);
-	    fseek(tmpd, 0L, SEEK_SET);
-
-	    if(cli_untgz(fileno(tmpd), dir)) {
-		perror("cli_untgz");
-		cli_errmsg("cli_cvdload(): Can't unpack CVD file.\n");
-		cli_rmdirs(dir);
-		free(dir);
-		fclose(tmpd);
-		unlink(tmp);
-		free(tmp);
-		return CL_ECVDEXTR;
-	    }
-
-	    fclose(tmpd);
-	    unlink(tmp);
-	    free(tmp);
-
-	    /* end */
 
     /* load extracted directory */
-    cl_loaddbdir(dir, root, signo);
+    ret = cl_load(dir, engine, signo, options);
 
     cli_rmdirs(dir);
     free(dir);
 
-    return 0;
+    return ret;
 }
