@@ -769,6 +769,7 @@ static iconv_t iconv_open_cached(const unsigned char* fromcode)
 	size_t idx;
 	const size_t fromcode_len = strlen((const char*)fromcode);
 	struct element * e;
+	iconv_t  iconv_struct;
 
 	init_iconv_pool_ifneeded();
 	cache = cache_get_tls_instance();/* gets TLS iconv pool */
@@ -786,6 +787,8 @@ static iconv_t iconv_open_cached(const unsigned char* fromcode)
 		return cache->tab[e->data];
 	}
 	cli_dbgmsg("iconv not found in cache, for encoding:%s\n",fromcode);
+	iconv_struct = iconv_open("UTF-16BE",(const char*)fromcode);
+	if(iconv_struct != (iconv_t)-1) {
 	idx = cache->last++;
 	if(idx >= cache->len) {
 		cache->len += 16;
@@ -798,16 +801,18 @@ static iconv_t iconv_open_cached(const unsigned char* fromcode)
 	}
 
 	hashtab_insert(&cache->hashtab, fromcode, fromcode_len, idx);
-	cache->tab[idx] = iconv_open("UTF-16BE",(const char*)fromcode);
+		cache->tab[idx] = iconv_struct;
 	cli_dbgmsg("iconv_open(),for:%s -> %p\n",fromcode,(void*)cache->tab[idx]);
 	return cache->tab[idx];
 }
+	return (iconv_t)-1;
+}
 
 
 /* tmp_m_area and conv->out_area are of size maxlen */
 unsigned char* encoding_norm_readline(struct entity_conv* conv, FILE* stream_in, m_area_t* in_m_area, const size_t maxlen)
 {
-	if(!conv || !conv->out_area.buffer || !conv->tmp_area.buffer)
+	if(!conv || !conv->out_area.buffer || !conv->tmp_area.buffer || maxlen<2 )
 		return NULL;
 	else {
 		/* stream_in|in_m_area ->(read_raw) conv->tmp_area -> (iconv) conv->out_area -> (normalize) conv->norm_area -> (cli_readline) return value*/
@@ -940,7 +945,7 @@ unsigned char* encoding_norm_readline(struct entity_conv* conv, FILE* stream_in,
 					cli_dbgmsg("Skipping null character in html stream\n");
 			}
 			}
-			else if((u16 < 0x80 && u16 >= 0x20) || isspace(u16)) {
+			else if((u16 < 0x80 && u16 >= 0x20) || (u16 <= 0xff && isspace(u16))) {
 				if(norm >= norm_end)
 					break;
 				if((unsigned char)u16 ==0)
