@@ -186,6 +186,8 @@ static const struct cli_smagic_s cli_smagic[] = {
     {"3c4f424a454354", "HTML data", CL_TYPE_HTML},      /* <OBJECT */
     {"3c696672616d65", "HTML data", CL_TYPE_HTML},      /* <iframe */
     {"3c494652414d45", "HTML data", CL_TYPE_HTML},      /* <IFRAME */
+    {"3c7461626c65",   "HTML data", CL_TYPE_HTML},	/* <table */
+    {"3c5441424c45",   "HTML data", CL_TYPE_HTML},	/* <TABLE */
 
     {"526172211a0700", "RAR-SFX", CL_TYPE_RARSFX},
     {"504b0304", "ZIP-SFX", CL_TYPE_ZIPSFX},
@@ -228,13 +230,16 @@ cli_file_t cli_filetype(const unsigned char *buf, size_t buflen)
 	}
     }
 
+/* improve or drop this code
+ * https://wwws.clamav.net/bugzilla/show_bug.cgi?id=373
+ *
     buflen < 25 ? (len = buflen) : (len = 25);
     for(i = 0; i < len; i++)
 	if(!iscntrl(buf[i]) && !isprint(buf[i]) && !internat[buf[i] & 0xff]) {
 	    text = 0;
 	    break;
 	}
-
+*/
     return text ? CL_TYPE_UNKNOWN_TEXT : CL_TYPE_UNKNOWN_DATA;
 }
 
