@@ -13,7 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
  
 #ifndef __HTMLNORM_H
@@ -22,10 +23,20 @@
 typedef struct tag_arguments_tag
 {
         int count;
+	int scanContents;
         unsigned char **tag;
         unsigned char **value;
+	struct blob   **contents; 
 } tag_arguments_t;
 
+typedef struct m_area_tag {
+	unsigned char *buffer;
+	off_t length;
+	off_t offset;
+} m_area_t;
+
+
+unsigned char *cli_readline(FILE *stream, m_area_t *m_area, unsigned int max_len);
 int html_normalise_mem(unsigned char *in_buff, off_t in_size, const char *dirname, tag_arguments_t *hrefs);
 int html_normalise_fd(int fd, const char *dirname, tag_arguments_t *hrefs);
 void html_tag_arg_free(tag_arguments_t *tags);
