@@ -13,7 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #include "clamav.h"
@@ -21,6 +22,8 @@
 #include "others.h"
 #include "cltypes.h"
 #include "matcher.h"
+#include "matcher-bm.h"
+#include "filetypes.h"
 
 /* TODO: Check prefix regularity and automatically transfer some signatures
  *	 to AC
@@ -30,16 +33,14 @@
 /* #define BM_TEST_OFFSET	5 */
 #define BM_BLOCK_SIZE	3
 
-#define MIN(a,b) (a < b) ? a : b
-#define HASH(a,b,c) 211 * (unsigned char) a + 37 * (unsigned char) b + (unsigned char) c
-#define DHASH(a,b,c) 211 * a + 37 * b + c
+#define HASH(a,b,c) (211 * a + 37 * b + c)
 
 
-int cli_bm_addpatt(struct cl_node *root, struct cli_bm_patt *pattern)
+int cli_bm_addpatt(struct cli_matcher *root, struct cli_bm_patt *pattern)
 {
 	int i;
 	uint16_t idx;
-	const char *pt = pattern->pattern;
+	const unsigned char *pt = pattern->pattern;
 	struct cli_bm_patt *prev, *next = NULL;
 
 
@@ -76,10 +77,10 @@ int cli_bm_addpatt(struct cl_node *root, struct cli_bm_patt *pattern)
     return 0;
 }
 
-int cli_bm_init(struct cl_node *root)
+int cli_bm_init(struct cli_matcher *root)
 {
 	unsigned int i;
-	unsigned int size = DHASH(256, 256, 256);
+	unsigned int size = HASH(256, 256, 256);
 
 
     cli_dbgmsg("in cli_bm_init()\n");
@@ -99,11 +100,11 @@ int cli_bm_init(struct cl_node *root)
     return 0;
 }
 
-void cli_bm_free(struct cl_node *root)
+void cli_bm_free(struct cli_matcher *root)
 {
 	struct cli_bm_patt *b1, *b2;
 	unsigned int i;
-	unsigned int size = DHASH(256, 256, 256);
+	unsigned int size = HASH(256, 256, 256);
 
 
     if(root->bm_shift)
@@ -128,13 +129,15 @@ void cli_bm_free(struct cl_node *root)
     }
 }
 
-int cli_bm_scanbuff(const char *buffer, unsigned int length, const char **virname, const struct cl_node *root, unsigned long int offset, unsigned short ftype, int fd)
+int cli_bm_scanbuff(const unsigned char *buffer, unsigned int length, const char **virname, const struct cli_matcher *root, unsigned long int offset, cli_file_t ftype, int fd)
 {
 	unsigned int i, j, shift, off, found = 0;
+	int idxtest;
 	uint16_t idx;
 	struct cli_bm_patt *p;
-	const char *bp;
-	char prefix;
+	const unsigned char *bp;
+	unsigned char prefix;
+	struct cli_target_info info;
 
 
     if(!root->bm_shift)
@@ -143,6 +146,8 @@ int cli_bm_scanbuff(const char *buffer, unsigned int length, const char **virnam
     if(length < BM_MIN_LENGTH)
 	return CL_CLEAN;
 
+    memset(&info, 0, sizeof(info));
+
     for(i = BM_MIN_LENGTH - BM_BLOCK_SIZE; i < length - BM_BLOCK_SIZE + 1; ) {
 	idx = HASH(buffer[i], buffer[i + 1], buffer[i + 2]);
 
@@ -167,6 +172,14 @@ int cli_bm_scanbuff(const char *buffer, unsigned int length, const char **virnam
 		}
 #endif
 
+		idxtest = MIN (p->length, length - off ) - 1;
+		if(idxtest >= 0) {
+		    if(bp[idxtest] != p->pattern[idxtest]) {
+			p = p->next;
+			continue;
+		    }
+		}
+
 		found = 1;
 		for(j = 0; j < p->length && off < length; j++, off++) {
 		    if(bp[j] != p->pattern[j]) {
@@ -180,7 +193,7 @@ int cli_bm_scanbuff(const char *buffer, unsigned int length, const char **virnam
 		    if(p->target || p->offset) {
 			off = offset + i - BM_MIN_LENGTH + BM_BLOCK_SIZE;
 
-			if((fd == -1 && !ftype) || !cli_validatesig(p->target, ftype, p->offset, off, fd, p->virname)) {
+			if((fd == -1 && !ftype) || !cli_validatesig(ftype, p->offset, off, &info, fd, p->virname)) {
 			    p = p->next;
 			    continue;
 			}
@@ -189,6 +202,9 @@ int cli_bm_scanbuff(const char *buffer, unsigned int length, const char **virnam
 		    if(virname)
 			*virname = p->virname;
 
+		    if(info.exeinfo.section)
+			free(info.exeinfo.section);
+
 		    return CL_VIRUS;
 		}
 
@@ -201,5 +217,8 @@ int cli_bm_scanbuff(const char *buffer, unsigned int length, const char **virnam
 	i += shift;
     }
 
-    return 0;
+    if(info.exeinfo.section)
+	free(info.exeinfo.section);
+
+    return CL_CLEAN;
 }
