@@ -72,19 +72,6 @@ static pthread_mutex_t cli_gentempname_mutex = PTHREAD_MUTEX_INITIALIZER;
 #include "md5.h"
 #include "cltypes.h"
 
-/* Maximum filenames under various systems - njh */
-#ifndef	NAME_MAX	/* e.g. Linux */
-# ifdef	MAXNAMELEN	/* e.g. Solaris */
-#   define	NAME_MAX	MAXNAMELEN
-# else
-#   ifdef	FILENAME_MAX	/* e.g. SCO */
-#     define	NAME_MAX	FILENAME_MAX
-#   else
-#     define	NAME_MAX	256
-#   endif
-# endif
-#endif
-
 #ifndef	O_BINARY
 #define	O_BINARY	0
 #endif
@@ -94,7 +81,7 @@ static pthread_mutex_t cli_gentempname_mutex = PTHREAD_MUTEX_INITIALIZER;
 #define       P_tmpdir        "C:\\WINDOWS\\TEMP"
 #endif
 
-#define CL_FLEVEL 13 /* don't touch it */
+#define CL_FLEVEL 14 /* don't touch it */
 
 short cli_debug_flag = 0, cli_leavetemps_flag = 0;
 
@@ -607,7 +594,7 @@ cli_rmdirs(const char *name)
 	if(strcmp(dent->d_name, "..") == 0)
 	    continue;
 
-	fname = cli_calloc(strlen(name) + strlen(dent->d_name) + 2, sizeof(char));
+	fname = cli_malloc(strlen(name) + strlen(dent->d_name) + 2, sizeof(char));
 	if(fname == NULL) {
 	    closedir(dd);
 	    return -1;
@@ -667,7 +654,7 @@ int cli_rmdirs(const char *dirname)
 #endif
 		{
 		    if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..")) {
-			fname = cli_calloc(strlen(dirname) + strlen(dent->d_name) + 2, sizeof(char));
+			fname = cli_malloc(strlen(dirname) + strlen(dent->d_name) + 2);
 			if(!fname) {
 			    closedir(dd);
 			    return -1;
@@ -923,3 +910,31 @@ int cli_bitset_test(bitset_t *bs, unsigned long bit_offset)
 	}
 	return (bs->bitset[char_offset] & ((unsigned char)1 << bit_offset));
 }
+
+
+/*
+ * Code from NJH
+ * Different operating systems allow different characters in their filenames
+ * FIXME: What does QNX want? There is no #ifdef C_QNX, but if there were
+ *      it may be best to treat it like MSDOS
+ */
+void
+cli_sanitise_filename(char *name)
+{
+	if(name == NULL)
+		return;
+
+	while(*name) {
+#ifdef  C_DARWIN
+		*name &= '\177';
+#endif
+		/* Also check for tab - "Heinz Martin" <Martin@hemag.ch> */
+#if     defined(MSDOS) || defined(C_CYGWIN) || defined(C_WINDOWS) || defined(C_OS2)
+		if(strchr("%/*?<>|\\\"+=,;:\t ~", *name))
+#else
+		if(*name == '/')
+#endif
+			*name = '_';
+		name++;
+	}
+}
