@@ -20,6 +20,10 @@
 #ifndef __OTHERS_H_LC
 #define __OTHERS_H_LC
 
+#if HAVE_CONFIG_H
+#include "clamav-config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include "cltypes.h"
@@ -46,6 +50,10 @@
 
 #define CLI_MAX_ALLOCATION 184549376
 
+#ifdef	HAVE_SYS_PARAM_H
+#include <sys/param.h>	/* for NAME_MAX */
+#endif
+
 /* Maximum filenames under various systems - njh */
 #ifndef	NAME_MAX	/* e.g. Linux */
 # ifdef	MAXNAMELEN	/* e.g. Solaris */
@@ -53,10 +61,17 @@
 # else
 #   ifdef	FILENAME_MAX	/* e.g. SCO */
 #     define	NAME_MAX	FILENAME_MAX
+#   else
+#     define    NAME_MAX        256
 #   endif
 # endif
 #endif
 
+#if NAME_MAX < 256
+#undef NAME_MAX
+#define NAME_MAX 256
+#endif
+
 /* internal clamav context */
 typedef struct {
     const char **virname;
@@ -73,6 +88,7 @@ typedef struct {
 #define SCAN_ARCHIVE	    (ctx->options & CL_SCAN_ARCHIVE)
 #define SCAN_MAIL	    (ctx->options & CL_SCAN_MAIL)
 #define SCAN_OLE2	    (ctx->options & CL_SCAN_OLE2)
+#define SCAN_PDF	    (ctx->options & CL_SCAN_PDF)
 #define SCAN_HTML	    (ctx->options & CL_SCAN_HTML)
 #define SCAN_PE		    (ctx->options & CL_SCAN_PE)
 #define SCAN_ELF	    (ctx->options & CL_SCAN_ELF)
@@ -163,4 +179,5 @@ bitset_t *cli_bitset_init(void);
 void cli_bitset_free(bitset_t *bs);
 int cli_bitset_set(bitset_t *bs, unsigned long bit_offset);
 int cli_bitset_test(bitset_t *bs, unsigned long bit_offset);
+void	cli_sanitise_filename(char *name);
 #endif
