@@ -534,14 +534,14 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 	cli_dbgmsg("NumberOfRvaAndSizes: %d\n", EC32(optional_hdr64.NumberOfRvaAndSizes));
     }
 
-    if (DETECT_BROKEN && (!(pe_plus?EC32(optional_hdr64.SectionAlignment):EC32(optional_hdr32.SectionAlignment)) || (pe_plus?EC32(optional_hdr64.SectionAlignment):EC32(optional_hdr32.SectionAlignment))%0x1000)) {
+    if (DETECT_BROKEN && (pe_plus?EC16(optional_hdr64.Subsystem):EC16(optional_hdr32.Subsystem))!= 1 && (!(pe_plus?EC32(optional_hdr64.SectionAlignment):EC32(optional_hdr32.SectionAlignment)) || (pe_plus?EC32(optional_hdr64.SectionAlignment):EC32(optional_hdr32.SectionAlignment))%0x1000)) {
         cli_dbgmsg("Bad virtual alignemnt\n");
         if(ctx->virname)
 	    *ctx->virname = "Broken.Executable";
 	return CL_VIRUS;
     }
 
-    if (DETECT_BROKEN && (!(pe_plus?EC32(optional_hdr64.FileAlignment):EC32(optional_hdr32.FileAlignment)) || (pe_plus?EC32(optional_hdr64.FileAlignment):EC32(optional_hdr32.FileAlignment))%0x200)) {
+    if (DETECT_BROKEN && (pe_plus?EC16(optional_hdr64.Subsystem):EC16(optional_hdr32.Subsystem))!= 1 && (!(pe_plus?EC32(optional_hdr64.FileAlignment):EC32(optional_hdr32.FileAlignment)) || (pe_plus?EC32(optional_hdr64.FileAlignment):EC32(optional_hdr32.FileAlignment))%0x200)) {
         cli_dbgmsg("Bad file alignemnt\n");
 	if(ctx->virname)
 	    *ctx->virname = "Broken.Executable";
@@ -553,7 +553,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 	    cli_dbgmsg("Subsystem: Unknown\n");
 	    break;
 	case 1:
-	    cli_dbgmsg("Subsystem: Native (a driver ?)\n");
+	    cli_dbgmsg("Subsystem: Native (svc)\n");
 	    break;
 	case 2:
 	    cli_dbgmsg("Subsystem: Win32 GUI\n");
@@ -643,6 +643,10 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 	exe_sections[i].raw = PEALIGN(EC32(section_hdr[i].PointerToRawData), falign);
 	exe_sections[i].rsz = PESALIGN(EC32(section_hdr[i].SizeOfRawData), falign);
 	exe_sections[i].ursz = EC32(section_hdr[i].SizeOfRawData);
+
+	if (!exe_sections[i].vsz && exe_sections[i].rsz)
+	    exe_sections[i].vsz=PESALIGN(EC32(section_hdr[i].SizeOfRawData), valign);
+
 	if (exe_sections[i].rsz && fsize>exe_sections[i].raw && !CLI_ISCONTAINED(0, (uint32_t) fsize, exe_sections[i].raw, exe_sections[i].rsz))
 	    exe_sections[i].rsz = fsize - exe_sections[i].raw;
 	
@@ -726,7 +730,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 	}
 
 	if(!i) {
-	    if (DETECT_BROKEN && EC32(section_hdr[i].VirtualAddress)!=valign) { /* Bad first section RVA */
+	    if (DETECT_BROKEN && (pe_plus?EC16(optional_hdr64.Subsystem):EC16(optional_hdr32.Subsystem))!= 1 && EC32(section_hdr[i].VirtualAddress)!=valign) { /* Bad first section RVA */
 	        cli_dbgmsg("First section is in the wrong place\n");
 	        if(ctx->virname)
 		    *ctx->virname = "Broken.Executable";
@@ -1328,6 +1332,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 		{
 		    cli_dbgmsg("Upack: Sizes exceeded (a: %u, b: %u, c: %ux, max: %lu)\n", a, b, c, ctx->limits->maxfilesize);
 		    free(section_hdr);
+		    free(exe_sections);
 		    if(BLOCKMAX) {
 			*ctx->virname = "PE.Upack.ExceededFileSize";
 			return CL_VIRUS;
@@ -1344,6 +1349,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 			
 		if((dest = (char *) cli_calloc(dsize, sizeof(char))) == NULL) {
 		    free(section_hdr);
+		    free(exe_sections);
 		    return CL_EMEM;
 		}
 		src = NULL;
@@ -1355,6 +1361,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 							*/
 		    cli_dbgmsg("Upack: Can't read raw data of section 0\n");
 		    free(section_hdr);
+		    free(exe_sections);
 		    free(dest);
 		    return CL_EIO;
 		}
@@ -1367,17 +1374,23 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 		if(read(desc, dest+EC32(section_hdr[1].VirtualAddress) - off, EC32(section_hdr[1].SizeOfRawData)) != EC32(section_hdr[1].SizeOfRawData)) {
 		    cli_dbgmsg("Upack: Can't read raw data of section 1\n");
 		    free(section_hdr);
+		    free(exe_sections);
 		    free(dest);
 		    return CL_EIO;
 		}
 
-		if(!(tempfile = cli_gentemp(NULL)))
+		if(!(tempfile = cli_gentemp(NULL))) {
+		    free(section_hdr);
+		    free(exe_sections);
+		    free(dest);
 		    return CL_EMEM;
+		}
 
 		if((file = open(tempfile, O_RDWR|O_CREAT|O_TRUNC, S_IRWXU)) < 0) {
 		    cli_dbgmsg("Upack: Can't create file %s\n", tempfile);
 		    free(tempfile);
 		    free(section_hdr);
+		    free(exe_sections);
 		    free(dest);
 		    return CL_EIO;
 		}
@@ -1393,6 +1406,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 				cli_dbgmsg("***** Scanning rebuilt PE file *****\n");
 				if(cli_magic_scandesc(file, ctx) == CL_VIRUS) {
 					free(section_hdr);
+					free(exe_sections);
 					close(file);
 					if(!cli_leavetemps_flag)
 						unlink(tempfile);
@@ -1405,6 +1419,7 @@ int cli_scanpe(int desc, cli_ctx *ctx)
 					unlink(tempfile);
 				free(tempfile);
 				free(section_hdr);
+				free(exe_sections);
 				return CL_CLEAN;
 
 			default: /* Everything gone wrong */
@@ -2555,7 +2570,6 @@ skip_upack_and_go_to_next_unpacker:
 	free(exe_sections);
 	return CL_EMEM;
       }
-      memset(dest, 0, dsize);
 
       lseek(desc, 0, SEEK_SET);
       if((size_t) cli_readn(desc, dest, headsize) != headsize) {
