@@ -18,125 +18,6 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *  MA 02110-1301, USA.
  *
- *  $Log: phishcheck.c,v $
- *  Revision 1.22  2007/02/12 20:34:31  tkojm
- *  fix hexurl regex (bb#288)
- *
- *  Revision 1.21  2007/02/11 00:41:13  tkojm
- *  remove some gcc warnings
- *
- *  Revision 1.20  2007/01/30 18:29:21  tkojm
- *  fix some includes
- *
- *  Revision 1.19  2007/01/13 19:39:21  tkojm
- *  phishing fixes (bb#157)
- *
- *  Revision 1.18  2007/01/12 17:36:53  tkojm
- *  add img url link-type filtering
- *
- *  Revision 1.17  2007/01/12 17:29:09  tkojm
- *  phishing patch from Edwin (closes bb#157, #174, #222, #224)
- *
- *  Revision 1.16  2006/12/20 01:23:50  tkojm
- *  options cleanup
- *
- *  Revision 1.15  2006/12/19 20:30:17  tkojm
- *  fix some compiler warnings
- *
- *  Revision 1.14  2006/10/14 23:52:01  tkojm
- *  code cleanup
- *
- *  Revision 1.13  2006/10/10 23:51:49  tkojm
- *  apply patches for the anti-phish code from Edwin
- *
- *  Revision 1.12  2006/10/08 18:55:15  tkojm
- *  fix crash in phishing code on database reload (Edvin Torok)
- *
- *  Revision 1.11  2006/10/07 11:00:46  tkojm
- *  make the experimental anti-phishing code more thread safe
- *
- *  Revision 1.10  2006/09/27 14:23:14  njh
- *  Ported to VS2005
- *
- *  Revision 1.9  2006/09/26 18:55:36  njh
- *  Fixed portability issues
- *
- *  Revision 1.8  2006/09/19 16:52:09  njh
- *  Fixed inconsistency between phishcheck.c and phishcheck.h
- *
- *  Revision 1.7  2006/09/18 17:10:07  njh
- *  Fix compilation error on Solaris 10
- *
- *  Revision 1.6  2006/09/16 15:49:27  acab
- *  phishing: fixed bugs and updated docs
- *
- *  Revision 1.5  2006/09/16 05:59:14  njh
- *  Fixed compiler warning
- *
- *  Revision 1.4  2006/09/16 05:39:54  njh
- *  Tidied print statement
- *
- *  Revision 1.3  2006/09/15 16:27:50  njh
- *  Better way to find string length in str_strip
- *
- *  Revision 1.2  2006/09/14 08:59:37  njh
- *  Fixed some NULL pointers
- *
- *  Revision 1.1  2006/09/12 19:38:39  acab
- *  Phishing module merge - libclamav
- *
- *  Revision 1.28  2006/09/09 09:49:27  edwin
- *  Fix Solaris compilation problem
- *
- *  Revision 1.27  2006/08/28 08:43:06  edwin
- *  Fixed a few minor leaks.
- *  Valgrind now says:"All heap blocks were freed -- no leaks are possible"
- *
- *  Revision 1.26  2006/08/20 21:18:11  edwin
- *  Added the script used to generate iana_tld.sh
- *  Added checks for phish_domaincheck_db
- *  Added phishing module design document from wiki (as discussed with aCaB).
- *  Updated .wdb/.pdb format documentation (in regex_list.c)
- *  Fixed some memory leaks in regex_list.c
- *  IOW: cleanups before the deadline.
- *  I consider my module to be ready for evaluation now.
- *
- *  Revision 1.25  2006/08/19 21:08:47  edwin
- *  Fixed:Forgot to add form tag handling when it contains images.
- *  Various fixes to get rid of gcc warnings.
- *
- *  Revision 1.24  2006/08/19 13:30:34  edwin
- *  iana_tld.h was missing from the list of header files.
- *  commentedout network code (unused currently)
- *
- *  Revision 1.23  2006/08/17 20:31:43  edwin
- *  Disable extracting hrefs from mails in mbox, if: we aren't scanning for phish, and mailfollowurls is off.
- *  Fix a still reachable leak. Remove unneeded build_regex_list export.
- *
- *  Revision 1.22  2006/08/12 14:35:34  edwin
- *  Fix some compiler warnings.
- *  Fix an assertion failure in regex_list.
- *  Interpret display links that start with http|https|ftp, always as an URL.
- *
- *  Revision 1.21  2006/08/06 20:27:07  edwin
- *  New option to enable phish scan for all domains (disabled by default).
- *  You will now have to run clamscan --phish-scan-alldomains to have any phishes detected.
- *  Updated phishcheck control flow to better incorporate the domainlist.
- *  Updated manpage with new options.
- *
- *  TODO:there is a still-reachable leak in regex_list.c
- *
- *  Revision 1.20  2006/08/01 20:19:14  edwin
- *  Integrate domainlist check into phishcheck. Warning: enabled by default.
- *  Regex bracket handling update.
- *  Better regex paranthesized & alternate expression handling.
- *
-
-case CL_PHISH_HOST_NOT_LISTED:
- return "Host not listed in .pdb -> not checked";*  Revision 1.19  2006/07/31 20:12:30  edwin
- *  Preliminary support for domain databases (domains to check by phishmodule)
- *  Better memory allocation failure handling in regex_list
- *
  */
 
 #if HAVE_CONFIG_H
@@ -182,8 +63,6 @@ case CL_PHISH_HOST_NOT_LISTED:
 #include <regex.h>
 #endif
 
-#include <pthread.h>
-
 #include "others.h"
 #include "defaults.h"
 #include "str.h"
@@ -654,7 +533,8 @@ static void get_domain(const struct phishcheck* pchk,struct string* dest,struct
 		const char* countrycode=tld+1;
 		tld = rfind(host->data,'.',tld-host->data-1);
 		if(!tld) {
-			cli_dbgmsg("PH:Weird, a name with only 2 levels (%s)\n",host->data);
+			cli_dbgmsg("PH:Weird, a name with only 2 levels (%s)\n",
+				host->data);
 			string_assign(dest,host);
 			return;
 		}
