@@ -17,6 +17,10 @@
  *  MA 02110-1301, USA.
  */
 
+#ifdef _MSC_VER
+#include <winsock.h> /* for Sleep() */
+#endif
+
 #if HAVE_CONFIG_H
 #include "clamav-config.h"
 #endif
@@ -28,7 +32,7 @@
 #ifdef	HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifndef	C_WINDOWS
+#ifndef C_WINDOWS
 #include <dirent.h>
 #endif
 #include <sys/types.h>
@@ -503,7 +507,11 @@ int cli_initengine(struct cl_engine **engine, unsigned int options)
 
 
     if(!*engine) {
-	cli_dbgmsg("Initializing the engine structure\n");
+#ifdef CL_EXPERIMENTAL
+	cli_dbgmsg("Initializing the engine ("VERSION"-exp)\n");
+#else
+	cli_dbgmsg("Initializing the engine ("VERSION")\n");
+#endif
 
 	*engine = (struct cl_engine *) cli_calloc(1, sizeof(struct cl_engine));
 	if(!*engine) {
@@ -1315,7 +1323,11 @@ static int cli_loaddbdir(const char *dirname, struct cl_engine **engine, unsigne
 
     cli_dbgmsg("cli_loaddbdir: Acquiring dbdir lock\n");
     while((lock = cli_readlockdb(dirname, 0)) == CL_ELOCKDB) {
+#ifdef C_WINDOWS
+	Sleep(5);
+#else
 	sleep(5);
+#endif
 	if(try++ > 24) {
 	    cli_errmsg("cl_load(): Unable to lock database directory: %s\n", dirname);
 	    return CL_ELOCKDB;
@@ -1695,6 +1707,17 @@ void cl_free(struct cl_engine *engine)
 	free(engine->md5_hlist);
     }
 
+    md5pt = engine->md5_sect;
+    while(md5pt) {
+	md5h = md5pt;
+	md5pt = md5pt->next;
+	free(md5h->md5);
+	free(md5h->virname);
+	if(md5h->viralias)
+	    free(md5h->viralias);
+	free(md5h);
+    }
+
     metapt = engine->zip_mlist;
     while(metapt) {
 	metah = metapt;
