@@ -18,114 +18,6 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *  MA 02110-1301, USA.
  *
- *  $Log: regex_list.c,v $
- *  Revision 1.18  2006/12/19 20:47:45  tkojm
- *  strict whitelisting
- *
- *  Revision 1.17  2006/12/19 20:30:17  tkojm
- *  fix some compiler warnings
- *
- *  Revision 1.16  2006/12/02 00:42:44  tkojm
- *  add functionality level support for .pdb/.wdb files
- *
- *  Revision 1.15  2006/11/15 15:26:54  tkojm
- *  pattern matcher accuracy improvements
- *
- *  Revision 1.14  2006/11/05 18:16:56  acab
- *  Patch for bug 52 from Edvin
- *
- *  Revision 1.13  2006/10/30 17:53:03  tkojm
- *  apply patch from Edvin reported by Luca
- *
- *  Revision 1.12  2006/10/28 15:34:40  tkojm
- *  .pdb/.wdb files now use colon as delimiter
- *
- *  Revision 1.11  2006/10/15 19:16:33  tkojm
- *  allow loading multiple .pdb/.wdb files
- *
- *  Revision 1.10  2006/10/14 23:52:02  tkojm
- *  code cleanup
- *
- *  Revision 1.9  2006/10/10 23:51:49  tkojm
- *  apply patches for the anti-phish code from Edwin
- *
- *  Revision 1.8  2006/10/08 18:55:15  tkojm
- *  fix crash in phishing code on database reload (Edvin Torok)
- *
- *  Revision 1.7  2006/10/07 11:00:46  tkojm
- *  make the experimental anti-phishing code more thread safe
- *
- *  Revision 1.6  2006/09/27 19:14:49  njh
- *  Fix segfault on Solaris
- *
- *  Revision 1.5  2006/09/26 18:55:36  njh
- *  Fixed portability issues
- *
- *  Revision 1.4  2006/09/25 18:27:00  njh
- *  Fix handling of escaped characters
- *
- *  Revision 1.3  2006/09/24 19:28:03  acab
- *  fixes for type "R" regex handler
- *
- *  Revision 1.2  2006/09/16 15:49:27  acab
- *  phishing: fixed bugs and updated docs
- *
- *  Revision 1.1  2006/09/12 19:38:39  acab
- *  Phishing module merge - libclamav
- *
- *  Revision 1.13  2006/09/11 19:25:08  edwin
- *  Non-printable characters in regex (although they are invalid inside an url, added some support for it).
- *
- *  Revision 1.12  2006/08/28 08:43:06  edwin
- *  Fixed a few minor leaks.
- *  Valgrind now says:"All heap blocks were freed -- no leaks are possible"
- *
- *  Revision 1.11  2006/08/20 21:18:11  edwin
- *  Added the script used to generate iana_tld.sh
- *  Added checks for phish_domaincheck_db
- *  Added phishing module design document from wiki (as discussed with aCaB).
- *  Updated .wdb/.pdb format documentation (in regex_list.c)
- *  Fixed some memory leaks in regex_list.c
- *  IOW: cleanups before the deadline.
- *  I consider my module to be ready for evaluation now.
- *
- *  Revision 1.10  2006/08/20 19:42:02  edwin
- *  Fix custom character class, and generic regex handling.
- *
- *  Revision 1.9  2006/08/19 21:08:47  edwin
- *  Fixed:Forgot to add form tag handling when it contains images.
- *  Various fixes to get rid of gcc warnings.
- *
- *  Revision 1.8  2006/08/19 09:26:51  edwin
- *  regex_list.c: Fixed regex alternatives handling (bug discovered with autotests).
- *  And forgot to commit manager.c last time.
- *
- *  Revision 1.7  2006/08/17 20:31:43  edwin
- *  Disable extracting hrefs from mails in mbox, if: we aren't scanning for phish, and mailfollowurls is off.
- *  Fix a still reachable leak. Remove unneeded build_regex_list export.
- *
- *  Revision 1.6  2006/08/12 14:35:34  edwin
- *  Fix some compiler warnings.
- *  Fix an assertion failure in regex_list.
- *  Interpret display links that start with http|https|ftp, always as an URL.
- *
- *  Revision 1.5  2006/08/06 20:27:07  edwin
- *  New option to enable phish scan for all domains (disabled by default).
- *  You will now have to run clamscan --phish-scan-alldomains to have any phishes detected.
- *  Updated phishcheck control flow to better incorporate the domainlist.
- *  Updated manpage with new options.
- *
- *  TODO:there is a still-reachable leak in regex_list.c
- *
- *  Revision 1.4  2006/08/01 20:19:15  edwin
- *  Integrate domainlist check into phishcheck. Warning: enabled by default.
- *  Regex bracket handling update.
- *  Better regex paranthesized & alternate expression handling.
- *
- *  Revision 1.3  2006/07/31 20:12:30  edwin
- *  Preliminary support for domain databases (domains to check by phishmodule)
- *  Better memory allocation failure handling in regex_list
- *
  */
 
 #if HAVE_CONFIG_H
@@ -1217,6 +1109,7 @@ static inline void tree_node_insert_nonbin(struct tree_node* node, struct tree_n
 				node->listend = 0;
 				node->next = new;
 				new->listend=1;
+				return;
 			}
 		node->u.children = cli_realloc(node->u.children,sizeof(node->u.children[0])*(2));
 		if(node->u.children) {
