@@ -100,19 +100,6 @@ extern short cli_leavetemps_flag;
 #include <stddef.h>
 #endif
 
-/* Maximum filenames under various systems - njh */
-#ifndef	NAME_MAX	/* e.g. Linux */
-# ifdef	MAXNAMELEN	/* e.g. Solaris */
-#   define	NAME_MAX	MAXNAMELEN
-# else
-#   ifdef	FILENAME_MAX	/* e.g. SCO */
-#     define	NAME_MAX	FILENAME_MAX
-#   else
-#     define	NAME_MAX	256
-#   endif
-# endif
-#endif
-
 #define MAX_MAIL_RECURSION  15
 
 static int cli_scanfile(const char *filename, cli_ctx *ctx);
@@ -959,7 +946,7 @@ int cli_scandir(const char *dirname, cli_ctx *ctx)
 	    {
 		if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..")) {
 		    /* build the full name */
-		    fname = cli_calloc(strlen(dirname) + strlen(dent->d_name) + 2, sizeof(char));
+		    fname = cli_malloc(strlen(dirname) + strlen(dent->d_name) + 2);
 		    if(!fname) {
 			closedir(dd);
 			return CL_EMEM;
@@ -1147,7 +1134,7 @@ static int cli_vba_scandir(const char *dirname, cli_ctx *ctx)
 	    {
 		if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..")) {
 		    /* build the full name */
-		    fname = cli_calloc(strlen(dirname) + strlen(dent->d_name) + 2, sizeof(char));
+		    fname = cli_malloc(strlen(dirname) + strlen(dent->d_name) + 2);
 		    if(!fname) {
 			ret = CL_EMEM;
 			break;
@@ -1690,33 +1677,25 @@ static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type)
 	return CL_EIO;
     }
 
-    if((ret = cli_scandesc(desc, ctx, ftrec, type, 0, &ftoffset)) == CL_VIRUS) {
-	cli_dbgmsg("%s found in descriptor %d.\n", *ctx->virname, desc);
-	return CL_VIRUS;
+    ret = cli_scandesc(desc, ctx, ftrec, type, 0, &ftoffset);
 
-    } else if(ret < 0) {
-	return ret;
-
-    } else if(ret >= CL_TYPENO) {
+    if(ret >= CL_TYPENO) {
 	lseek(desc, 0, SEEK_SET);
 
-	if((nret = cli_scandesc(desc, ctx, 0, ret, 1, NULL)) == CL_VIRUS) {
+	nret = cli_scandesc(desc, ctx, 0, ret, 1, NULL);
+	if(nret == CL_VIRUS)
 	    cli_dbgmsg("%s found in descriptor %d when scanning file type %u\n", *ctx->virname, desc, ret);
-	    return CL_VIRUS;
-	}
 
 	ret == CL_TYPE_MAIL ? ctx->mrec++ : ctx->arec++;
-	switch(ret) {
+	if(nret != CL_VIRUS) switch(ret) {
 	    case CL_TYPE_HTML:
 		if(SCAN_HTML && type == CL_TYPE_UNKNOWN_TEXT && (DCONF_DOC & DOC_CONF_HTML))
-		    if((nret = cli_scanhtml(desc, ctx)) == CL_VIRUS)
-			return CL_VIRUS;
+		    nret = cli_scanhtml(desc, ctx);
 		break;
 
 	    case CL_TYPE_MAIL:
 		if(SCAN_MAIL && type == CL_TYPE_UNKNOWN_TEXT && (DCONF_MAIL & MAIL_CONF_MBOX))
-		    if((nret = cli_scanmail(desc, ctx)) == CL_VIRUS)
-			return CL_VIRUS;
+		    nret = cli_scanmail(desc, ctx);
 		break;
 
 	    case CL_TYPE_RARSFX:
@@ -1744,15 +1723,6 @@ static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type)
 			    fpt = fpt->next;
 			}
 		    }
-
-		    while(ftoffset) {
-			fpt = ftoffset;
-			ftoffset = ftoffset->next;
-			free(fpt);
-		    }
-
-		    if(nret == CL_VIRUS)
-			return nret;
 		}
 		break;
 
@@ -1763,6 +1733,15 @@ static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type)
 	ret = nret;
     }
 
+    while(ftoffset) {
+	fpt = ftoffset;
+	ftoffset = ftoffset->next;
+	free(fpt);
+    }
+
+    if(ret == CL_VIRUS)
+	cli_dbgmsg("%s found in descriptor %d\n", *ctx->virname, desc);
+
     return ret;
 }
 
@@ -1928,7 +1907,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 	    break;
 
 	case CL_TYPE_PDF:
-	    if(SCAN_ARCHIVE && (DCONF_DOC & DOC_CONF_PDF))    /* you may wish to change this line */
+	    if(SCAN_PDF && (DCONF_DOC & DOC_CONF_PDF))
 		ret = cli_scanpdf(desc, ctx);
 	    break;
 
