@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 - 2005 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2004 - 2007 Tomasz Kojm <tkojm@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,6 @@
 #include <errno.h>
 
 #include "shared/cfgparser.h"
-#include "shared/memory.h"
 #include "shared/output.h"
 
 #include "libclamav/clamav.h"
@@ -49,6 +48,12 @@
 #define	O_BINARY	0
 #endif
 
+#ifdef CL_EXPERIMENTAL
+#define VERSION_EXP	VERSION"-exp"
+#else
+#define VERSION_EXP	VERSION
+#endif
+
 char *freshdbdir(void)
 {
 	struct cl_cvd *d1, *d2;
@@ -63,7 +68,7 @@ char *freshdbdir(void)
     if((copt = getcfg(CONFDIR"/clamd.conf", 0))) {
 	if((cpt = cfgopt(copt, "DatabaseDirectory"))->enabled || (cpt = cfgopt(copt, "DataDirectory"))->enabled) {
 	    if(strcmp(dbdir, cpt->strarg)) {
-		    char *daily = (char *) mmalloc(strlen(cpt->strarg) + strlen(dbdir) + 30);
+		    char *daily = (char *) malloc(strlen(cpt->strarg) + strlen(dbdir) + 30);
 		sprintf(daily, "%s/daily.cvd", cpt->strarg);
 		if(stat(daily, &foo) == -1)
 		    sprintf(daily, "%s/daily.inc/daily.info", cpt->strarg);
@@ -107,7 +112,7 @@ void print_version(void)
 
 
     dbdir = freshdbdir();
-    if(!(path = mmalloc(strlen(dbdir) + 30))) {
+    if(!(path = malloc(strlen(dbdir) + 30))) {
 	free(dbdir);
 	return;
     }
@@ -119,10 +124,11 @@ void print_version(void)
 
     if((daily = cl_cvdhead(path))) {
 	    time_t t = (time_t) daily->stime;
-	printf("ClamAV "VERSION"/%d/%s", daily->version, ctime(&t));
+
+	printf("ClamAV "VERSION_EXP"/%d/%s", daily->version, ctime(&t));
 	cl_cvdfree(daily);
     } else {
-	printf("ClamAV "VERSION"\n");
+	printf("ClamAV "VERSION_EXP"\n");
     }
 
     free(path);
@@ -179,66 +185,6 @@ int filecopy(const char *src, const char *dest)
 
 }
 
-int rmdirs(const char *dirname)
-{
-	DIR *dd;
-	struct dirent *dent;
-	struct stat maind, statbuf;
-	char *fname;
-
-
-    if((dd = opendir(dirname)) != NULL) {
-	while(stat(dirname, &maind) != -1) {
-	    if(!rmdir(dirname)) break;
-	    if(errno != ENOTEMPTY && errno != EEXIST && errno != EBADF) {
-		closedir(dd);
-		return 0;
-	    }
-
-	    while((dent = readdir(dd))) {
-#if   (!defined(C_CYGWIN)) && (!defined(C_INTERIX)) && (!defined(C_WINDOWS))
-		if(dent->d_ino)
-#endif
-		{
-		    if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..")) {
-			fname = mcalloc(strlen(dirname) + strlen(dent->d_name) + 2, sizeof(char));
-#ifdef	C_WINDOWS
-			sprintf(fname, "%s\\%s", dirname, dent->d_name);
-#else
-			sprintf(fname, "%s/%s", dirname, dent->d_name);
-#endif
-
-			/* stat the file */
-			if(lstat(fname, &statbuf) != -1) {
-			    if(S_ISDIR(statbuf.st_mode) && !S_ISLNK(statbuf.st_mode)) {
-				if(rmdir(fname) == -1) { /* can't be deleted */
-				    if(errno == EACCES) {
-					closedir(dd);
-					free(fname);
-					return 1;
-				    }
-				    rmdirs(fname);
-				}
-			    } else
-				unlink(fname);
-			}
-
-			free(fname);
-		    }
-		}
-	    }
-
-	    rewinddir(dd);
-	}
-
-    } else { 
-	return 1;
-    }
-
-    closedir(dd);
-    return 0;
-}
-
 int dircopy(const char *src, const char *dest)
 {
 	DIR *dd;
@@ -248,7 +194,7 @@ int dircopy(const char *src, const char *dest)
 
 
     if(stat(dest, &sb) == -1) {
-	if(mkdir(dest, 0700)) {
+	if(mkdir(dest, 0755)) {
 	    /* mprintf("!dircopy: Can't create temporary directory %s\n", dest); */
 	    return -1;
 	}
@@ -272,7 +218,7 @@ int dircopy(const char *src, const char *dest)
 
 	    if(filecopy(spath, dpath) == -1) {
 		/* mprintf("!dircopy: Can't copy %s to %s\n", spath, dpath); */
-		rmdirs(dest);
+		cli_rmdirs(dest);
 		closedir(dd);
 		return -1;
 	    }
@@ -327,7 +273,7 @@ void daemonize(void)
 	    close(i);
 
     } else {
-	close(0);
+	dup2(i, 0);
 	dup2(i, 1);
 	dup2(i, 2);
     }
